@@ -1,18 +1,18 @@
 use std::path::{Path, PathBuf};
 
 use anyhow::Result;
-use image::{DynamicImage, ExtendedColorType, ImageDecoder, ImageEncoder, ImageError, ImageReader, ImageResult, Limits, codecs::{jpeg::JpegEncoder, png::PngEncoder}, imageops::FilterType, metadata::Orientation};
+use image::{DynamicImage, ImageDecoder, ImageError, ImageReader, Limits, codecs::{jpeg::JpegEncoder, png::PngEncoder}, imageops::FilterType, metadata::Orientation};
 use ratatui::layout::Rect;
 use yazi_config::YAZI;
 use yazi_fs::provider::{Provider, local::Local};
 
-use crate::Dimension;
+use crate::{Dimension, Icc};
 
 pub struct Image;
 
 impl Image {
 	pub async fn precache(src: PathBuf, cache: &Path) -> Result<()> {
-		let (mut img, orientation, icc) = Self::decode_from(src).await?;
+		let (mut img, orientation) = Self::decode_from(src).await?;
 		let (w, h) = Self::flip_size(orientation, (YAZI.preview.max_width, YAZI.preview.max_height));
 
 		let buf = tokio::task::spawn_blocking(move || {
@@ -25,14 +25,11 @@ impl Image {
 
 			let mut buf = Vec::new();
 			if img.color().has_alpha() {
-				let rgba = img.into_rgba8();
-				let mut encoder = PngEncoder::new(&mut buf);
-				icc.map(|b| encoder.set_icc_profile(b));
-				encoder.write_image(&rgba, rgba.width(), rgba.height(), ExtendedColorType::Rgba8)?;
+				let encoder = PngEncoder::new(&mut buf);
+				img.write_with_encoder(encoder)?;
 			} else {
-				let mut encoder = JpegEncoder::new_with_quality(&mut buf, YAZI.preview.image_quality);
-				icc.map(|b| encoder.set_icc_profile(b));
-				encoder.encode_image(&img.into_rgb8())?;
+				let encoder = JpegEncoder::new_with_quality(&mut buf, YAZI.preview.image_quality);
+				img.write_with_encoder(encoder)?;
 			}
 
 			Ok::<_, ImageError>(buf)
@@ -43,7 +40,7 @@ impl Image {
 	}
 
 	pub(super) async fn downscale(path: PathBuf, rect: Rect) -> Result<DynamicImage> {
-		let (mut img, orientation, _) = Self::decode_from(path).await?;
+		let (mut img, orientation) = Self::decode_from(path).await?;
 		let (w, h) = Self::flip_size(orientation, Self::max_pixel(rect));
 
 		// Fast path.
@@ -96,7 +93,7 @@ impl Image {
 		}
 	}
 
-	async fn decode_from(path: PathBuf) -> ImageResult<(DynamicImage, Orientation, Option<Vec<u8>>)> {
+	async fn decode_from(path: PathBuf) -> Result<(DynamicImage, Orientation)> {
 		let mut limits = Limits::no_limits();
 		if YAZI.tasks.image_alloc > 0 {
 			limits.max_alloc = Some(YAZI.tasks.image_alloc as u64);
@@ -114,9 +111,7 @@ impl Image {
 
 			let mut decoder = reader.with_guessed_format()?.into_decoder()?;
 			let orientation = decoder.orientation().unwrap_or(Orientation::NoTransforms);
-			let icc = decoder.icc_profile().unwrap_or_default();
-
-			Ok((DynamicImage::from_decoder(decoder)?, orientation, icc))
+			Ok((Icc::transform(decoder)?, orientation))
 		})
 		.await
 		.map_err(|e| ImageError::IoError(e.into()))?
