@@ -1,6 +1,6 @@
 yazi_macro::mod_pub!(drivers);
 
-yazi_macro::mod_flat!(adapter brand dimension emulator image info mux unknown);
+yazi_macro::mod_flat!(adapter brand dimension emulator icc image info mux unknown);
 
 use yazi_shared::{RoCell, SyncCell, in_wsl};
 
