@@ -1,29 +1,43 @@
 use std::{borrow::Cow, fmt::Display};
 
 use mlua::{ExternalError, FromLua, Lua, MetaMethod, UserData, UserDataFields, UserDataMethods, Value};
+use yazi_shared::SStr;
 
 const EXPECTED: &str = "expected a Error";
 
 pub enum Error {
 	Io(std::io::Error),
-	IoKind(std::io::ErrorKind),
+	Fs(yazi_fs::error::Error),
 	Serde(serde_json::Error),
-	Custom(String),
+	Custom(SStr),
 }
 
 impl Error {
 	pub fn install(lua: &Lua) -> mlua::Result<()> {
-		let new = lua.create_function(|_, msg: String| Ok(Error::Custom(msg)))?;
+		let custom = lua.create_function(|_, msg: String| Ok(Self::custom(msg)))?;
 
-		lua.globals().raw_set("Error", lua.create_table_from([("custom", new)])?)
+		let fs = lua.create_function(|_, value: Value| {
+			Ok(Self::Fs(match value {
+				Value::Table(t) => yazi_fs::error::Error::custom(
+					&t.raw_get::<mlua::String>("kind")?.to_str()?,
+					t.raw_get("code")?,
+					&t.raw_get::<mlua::String>("message")?.to_str()?,
+				)?,
+				_ => Err("expected a table".into_lua_err())?,
+			}))
+		})?;
+
+		lua.globals().raw_set("Error", lua.create_table_from([("custom", custom), ("fs", fs)])?)
 	}
 
-	fn to_string(&self) -> Cow<str> {
+	pub fn custom(msg: impl Into<SStr>) -> Self { Self::Custom(msg.into()) }
+
+	pub fn into_string(self) -> SStr {
 		match self {
-			Error::Io(e) => Cow::Owned(e.to_string()),
-			Error::IoKind(e) => Cow::Owned(e.to_string()),
-			Error::Serde(e) => Cow::Owned(e.to_string()),
-			Error::Custom(s) => Cow::Borrowed(s),
+			Self::Io(e) => Cow::Owned(e.to_string()),
+			Self::Fs(e) => Cow::Owned(e.to_string()),
+			Self::Serde(e) => Cow::Owned(e.to_string()),
+			Self::Custom(s) => s,
 		}
 	}
 }
@@ -31,10 +45,10 @@ impl Error {
 impl Display for Error {
 	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
 		match self {
-			Error::Io(e) => write!(f, "{e}"),
-			Error::IoKind(e) => write!(f, "{e}"),
-			Error::Serde(e) => write!(f, "{e}"),
-			Error::Custom(s) => write!(f, "{s}"),
+			Self::Io(e) => write!(f, "{e}"),
+			Self::Fs(e) => write!(f, "{e}"),
+			Self::Serde(e) => write!(f, "{e}"),
+			Self::Custom(s) => write!(f, "{s}"),
 		}
 	}
 }
@@ -52,7 +66,15 @@ impl UserData for Error {
 	fn add_fields<F: UserDataFields<Self>>(fields: &mut F) {
 		fields.add_field_method_get("code", |_, me| {
 			Ok(match me {
-				Error::Io(e) => e.raw_os_error(),
+				Self::Io(e) => e.raw_os_error(),
+				Self::Fs(e) => e.raw_os_error(),
+				_ => None,
+			})
+		});
+		fields.add_field_method_get("kind", |_, me| {
+			Ok(match me {
+				Self::Io(e) => Some(yazi_fs::error::Error::from(e.kind()).kind_str()),
+				Self::Fs(e) => Some(e.kind_str()),
 				_ => None,
 			})
 		});
@@ -60,7 +82,10 @@ impl UserData for Error {
 
 	fn add_methods<M: UserDataMethods<Self>>(methods: &mut M) {
 		methods.add_meta_method(MetaMethod::ToString, |lua, me, ()| {
-			lua.create_string(me.to_string().as_ref())
+			Ok(match me {
+				Self::Io(_) | Self::Fs(_) | Self::Serde(_) => lua.create_string(me.to_string()),
+				Self::Custom(s) => lua.create_string(&**s),
+			})
 		});
 		methods.add_meta_function(MetaMethod::Concat, |lua, (lhs, rhs): (Value, Value)| {
 			match (lhs, rhs) {
