@@ -5,7 +5,7 @@ use super::Actions;
 
 impl Actions {
 	pub(super) fn clear_cache() {
-		if YAZI.preview.cache_dir == Xdg::cache_dir() {
+		if YAZI.preview.cache_dir == *Xdg::cache_dir() {
 			println!("Clearing cache directory: \n{:?}", YAZI.preview.cache_dir);
 			std::fs::remove_dir_all(&YAZI.preview.cache_dir).unwrap();
 		} else {
