@@ -1,6 +1,6 @@
 use ratatui::layout::Rect;
 
-#[derive(Clone, Copy, Default, PartialEq, Eq)]
+#[derive(Clone, Copy, Default, Eq, PartialEq)]
 pub struct Layout {
 	pub current:  Rect,
 	pub preview:  Rect,
@@ -12,5 +12,5 @@ impl Layout {
 		Self { current: Rect::ZERO, preview: Rect::ZERO, progress: Rect::ZERO }
 	}
 
-	pub const fn limit(&self) -> usize { self.current.height as _ }
+	pub const fn folder_limit(self) -> usize { self.current.height as _ }
 }
