@@ -1,7 +1,7 @@
 use std::time::{Duration, Instant};
 
 use unicode_width::UnicodeWidthStr;
-use yazi_proxy::options::{NotifyLevel, NotifyOpt};
+use yazi_parser::app::{NotifyLevel, NotifyOpt};
 
 use super::NOTIFY_BORDER;
 
@@ -37,7 +37,6 @@ impl From<NotifyOpt> for Message {
 }
 
 impl Message {
-	#[inline]
 	pub fn height(&self, width: u16) -> usize {
 		let lines = ratatui::widgets::Paragraph::new(self.content.as_str())
 			.wrap(ratatui::widgets::Wrap { trim: false })
