@@ -1,6 +1,6 @@
 use std::{borrow::Cow, mem};
 
-use yazi_config::{WHICH, keymap::ChordCow, which::SortBy};
+use yazi_config::{YAZI, keymap::ChordCow, which::SortBy};
 use yazi_shared::{natsort, translit::Transliterator};
 
 #[derive(Clone, Copy, PartialEq)]
@@ -14,10 +14,10 @@ pub struct WhichSorter {
 impl Default for WhichSorter {
 	fn default() -> Self {
 		Self {
-			by:        WHICH.sort_by,
-			sensitive: WHICH.sort_sensitive,
-			reverse:   WHICH.sort_reverse,
-			translit:  WHICH.sort_translit,
+			by:        YAZI.which.sort_by,
+			sensitive: YAZI.which.sort_sensitive,
+			reverse:   YAZI.which.sort_reverse,
+			translit:  YAZI.which.sort_translit,
 		}
 	}
 }
