@@ -1,12 +1,14 @@
-use std::{borrow::Cow, collections::HashMap};
+use std::{any::TypeId, borrow::Cow};
 
+use hashbrown::HashMap;
 use mlua::{ExternalError, IntoLua, Lua, MultiValue, Table, Value};
-use yazi_shared::{OrderedFloat, event::{Data, DataKey}, replace_cow};
+use ordered_float::OrderedFloat;
+use yazi_shared::{data::{Data, DataKey}, replace_cow};
 
 pub struct Sendable;
 
 impl Sendable {
-	pub fn value_to_data(value: Value) -> mlua::Result<Data> {
+	pub fn value_to_data(lua: &Lua, value: Value) -> mlua::Result<Data> {
 		Ok(match value {
 			Value::Nil => Data::Nil,
 			Value::Boolean(b) => Data::Boolean(b),
@@ -15,7 +17,7 @@ impl Sendable {
 			Value::Number(n) => Data::Number(n),
 			Value::String(b) => {
 				if let Ok(s) = b.to_str() {
-					Data::String(s.to_owned())
+					Data::String(s.to_owned().into())
 				} else {
 					Data::Bytes(b.as_bytes().to_owned())
 				}
@@ -29,7 +31,7 @@ impl Sendable {
 					if k == DataKey::Integer(i) {
 						i += 1;
 					}
-					map.insert(k, Self::value_to_data(v)?);
+					map.insert(k, Self::value_to_data(lua, v)?);
 				}
 
 				if map.len() == i as usize - 1 {
@@ -40,21 +42,24 @@ impl Sendable {
 			}
 			Value::Function(_) => Err("function is not supported".into_lua_err())?,
 			Value::Thread(_) => Err("thread is not supported".into_lua_err())?,
-			Value::UserData(ud) => {
-				if let Ok(t) = ud.take::<yazi_binding::Url>() {
-					Data::Url(t.into())
-				} else if let Ok(t) = ud.take::<yazi_binding::Urn>() {
-					Data::Urn(t.into())
-				} else if let Ok(t) = ud.borrow::<yazi_binding::Id>() {
-					Data::Id(**t)
-				} else if let Ok(t) = ud.take::<yazi_fs::FilesOp>() {
-					Data::Any(Box::new(t))
-				} else if let Ok(t) = ud.take::<super::body::BodyYankIter>() {
-					Data::Any(Box::new(t))
-				} else {
-					Err(format!("unsupported userdata included: {ud:?}").into_lua_err())?
+			Value::UserData(ud) => match ud.type_id() {
+				Some(t) if t == TypeId::of::<yazi_binding::Url>() => {
+					Data::Url(ud.take::<yazi_binding::Url>()?.into())
 				}
-			}
+				Some(t) if t == TypeId::of::<yazi_binding::Path>() => {
+					Data::Path(ud.take::<yazi_binding::Path>()?.into())
+				}
+				Some(t) if t == TypeId::of::<yazi_binding::Id>() => {
+					Data::Id(**ud.borrow::<yazi_binding::Id>()?)
+				}
+				Some(t) if t == TypeId::of::<yazi_fs::FilesOp>() => {
+					Data::Any(Box::new(ud.take::<yazi_fs::FilesOp>()?))
+				}
+				Some(t) if t == TypeId::of::<yazi_parser::mgr::UpdateYankedIter>() => {
+					Data::Any(Box::new(ud.take::<yazi_parser::mgr::UpdateYankedIter>()?.into_opt(lua)?))
+				}
+				_ => Err(format!("unsupported userdata included: {ud:?}").into_lua_err())?,
+			},
 			Value::Error(_) => Err("error is not supported".into_lua_err())?,
 			Value::Other(..) => Err("unknown data is not supported".into_lua_err())?,
 		})
@@ -78,14 +83,16 @@ impl Sendable {
 				Value::Table(tbl)
 			}
 			Data::Url(u) => yazi_binding::Url::new(u).into_lua(lua)?,
-			Data::Urn(u) => yazi_binding::Urn::new(u).into_lua(lua)?,
-			Data::Any(a) => Value::UserData(if a.is::<yazi_fs::FilesOp>() {
-				lua.create_any_userdata(*a.downcast::<yazi_fs::FilesOp>().unwrap())?
-			} else if a.is::<super::body::BodyYankIter>() {
-				lua.create_userdata(*a.downcast::<super::body::BodyYankIter>().unwrap())?
-			} else {
-				Err("unsupported Data::Any included".into_lua_err())?
-			}),
+			Data::Path(u) => yazi_binding::Path::new(u).into_lua(lua)?,
+			Data::Any(a) => {
+				if a.is::<yazi_fs::FilesOp>() {
+					lua.create_any_userdata(*a.downcast::<yazi_fs::FilesOp>().unwrap())?.into_lua(lua)?
+				} else if a.is::<yazi_parser::mgr::UpdateYankedOpt>() {
+					a.downcast::<yazi_parser::mgr::UpdateYankedOpt>().unwrap().into_lua(lua)?
+				} else {
+					Err("unsupported Data::Any included".into_lua_err())?
+				}
+			}
 			data => Self::data_to_value_ref(lua, &data)?,
 		})
 	}
@@ -96,7 +103,7 @@ impl Sendable {
 			Data::Boolean(b) => Value::Boolean(*b),
 			Data::Integer(i) => Value::Integer(*i),
 			Data::Number(n) => Value::Number(*n),
-			Data::String(s) => Value::String(lua.create_string(s)?),
+			Data::String(s) => Value::String(lua.create_string(&**s)?),
 			Data::List(l) => {
 				let mut vec = Vec::with_capacity(l.len());
 				for v in l {
@@ -113,31 +120,33 @@ impl Sendable {
 				Value::Table(tbl)
 			}
 			Data::Id(i) => yazi_binding::Id(*i).into_lua(lua)?,
-			Data::Url(u) => yazi_binding::Url::new(u.clone()).into_lua(lua)?,
-			Data::Urn(u) => yazi_binding::Urn::new(u.clone()).into_lua(lua)?,
+			Data::Url(u) => yazi_binding::Url::new(u).into_lua(lua)?,
+			Data::Path(u) => yazi_binding::Path::new(u).into_lua(lua)?,
 			Data::Bytes(b) => Value::String(lua.create_string(b)?),
-			Data::Any(a) => Value::UserData(if let Some(t) = a.downcast_ref::<yazi_fs::FilesOp>() {
-				lua.create_any_userdata(t.clone())?
-			} else if let Some(t) = a.downcast_ref::<super::body::BodyYankIter>() {
-				lua.create_userdata(t.clone())?
-			} else {
-				Err("unsupported Data::Any included".into_lua_err())?
-			}),
+			Data::Any(a) => {
+				if let Some(t) = a.downcast_ref::<yazi_fs::FilesOp>() {
+					lua.create_any_userdata(t.clone())?.into_lua(lua)?
+				} else if let Some(t) = a.downcast_ref::<yazi_parser::mgr::UpdateYankedOpt>() {
+					t.clone().into_lua(lua)?
+				} else {
+					Err("unsupported Data::Any included".into_lua_err())?
+				}
+			}
 		})
 	}
 
-	pub fn table_to_args(t: Table) -> mlua::Result<HashMap<DataKey, Data>> {
+	pub fn table_to_args(lua: &Lua, t: Table) -> mlua::Result<HashMap<DataKey, Data>> {
 		let mut args = HashMap::with_capacity(t.raw_len());
 		for pair in t.pairs::<Value, Value>() {
 			let (k, v) = pair?;
 			match k {
 				Value::Integer(i) if i > 0 => {
-					args.insert(DataKey::Integer(i - 1), Self::value_to_data(v)?);
+					args.insert(DataKey::Integer(i - 1), Self::value_to_data(lua, v)?);
 				}
 				Value::String(s) => {
 					args.insert(
 						DataKey::String(Cow::Owned(s.to_str()?.replace('_', "-"))),
-						Self::value_to_data(v)?,
+						Self::value_to_data(lua, v)?,
 					);
 				}
 				_ => return Err("invalid key in Cmd".into_lua_err()),
@@ -152,7 +161,7 @@ impl Sendable {
 		for (k, v) in args {
 			match k {
 				DataKey::Integer(i) => tbl.raw_set(i + 1, Self::data_to_value(lua, v)?),
-				DataKey::String(s) => tbl.raw_set(replace_cow(&s, "-", "_"), Self::data_to_value(lua, v)?),
+				DataKey::String(s) => tbl.raw_set(replace_cow(s, "-", "_"), Self::data_to_value(lua, v)?),
 				_ => Err("invalid key in Data".into_lua_err()),
 			}?;
 		}
@@ -166,7 +175,7 @@ impl Sendable {
 			match k {
 				DataKey::Integer(i) => tbl.raw_set(i + 1, Self::data_to_value_ref(lua, v)?),
 				DataKey::String(s) => {
-					tbl.raw_set(replace_cow(s, "-", "_"), Self::data_to_value_ref(lua, v)?)
+					tbl.raw_set(replace_cow(&**s, "-", "_"), Self::data_to_value_ref(lua, v)?)
 				}
 				_ => Err("invalid key in Data".into_lua_err()),
 			}?;
@@ -178,8 +187,8 @@ impl Sendable {
 		data.into_iter().map(|d| Self::data_to_value(lua, d)).collect()
 	}
 
-	pub fn values_to_list(values: MultiValue) -> mlua::Result<Vec<Data>> {
-		values.into_iter().map(Self::value_to_data).collect()
+	pub fn values_to_list(lua: &Lua, values: MultiValue) -> mlua::Result<Vec<Data>> {
+		values.into_iter().map(|v| Self::value_to_data(lua, v)).collect()
 	}
 }
 
@@ -187,35 +196,41 @@ impl Sendable {
 	fn value_to_key(value: Value) -> mlua::Result<DataKey> {
 		Ok(match value {
 			Value::Nil => DataKey::Nil,
-			Value::Boolean(v) => DataKey::Boolean(v),
+			Value::Boolean(b) => DataKey::Boolean(b),
 			Value::LightUserData(_) => Err("light userdata is not supported".into_lua_err())?,
-			Value::Integer(v) => DataKey::Integer(v),
-			Value::Number(v) => DataKey::Number(OrderedFloat::new(v)),
-			Value::String(v) => DataKey::String(Cow::Owned(v.to_str()?.to_owned())),
+			Value::Integer(i) => DataKey::Integer(i),
+			Value::Number(n) => DataKey::Number(OrderedFloat(n)),
+			Value::String(s) => {
+				if let Ok(s) = s.to_str() {
+					DataKey::String(s.to_owned().into())
+				} else {
+					DataKey::Bytes(s.as_bytes().to_owned())
+				}
+			}
 			Value::Table(_) => Err("table is not supported".into_lua_err())?,
 			Value::Function(_) => Err("function is not supported".into_lua_err())?,
 			Value::Thread(_) => Err("thread is not supported".into_lua_err())?,
-			Value::UserData(ud) => {
-				if let Ok(t) = ud.take::<yazi_binding::Url>() {
-					DataKey::Url(t.into())
-				} else if let Ok(t) = ud.take::<yazi_binding::Urn>() {
-					DataKey::Urn(t.into())
-				} else if let Ok(t) = ud.borrow::<yazi_binding::Id>() {
-					DataKey::Id(**t)
-				} else {
-					Err(format!("unsupported userdata included: {ud:?}").into_lua_err())?
+			Value::UserData(ud) => match ud.type_id() {
+				Some(t) if t == TypeId::of::<yazi_binding::Url>() => {
+					DataKey::Url(ud.take::<yazi_binding::Url>()?.into())
 				}
-			}
+				Some(t) if t == TypeId::of::<yazi_binding::Path>() => {
+					DataKey::Path(ud.take::<yazi_binding::Path>()?.into())
+				}
+				Some(t) if t == TypeId::of::<yazi_binding::Id>() => {
+					DataKey::Id(**ud.borrow::<yazi_binding::Id>()?)
+				}
+				_ => Err(format!("unsupported userdata included: {ud:?}").into_lua_err())?,
+			},
 			Value::Error(_) => Err("error is not supported".into_lua_err())?,
 			Value::Other(..) => Err("unknown data is not supported".into_lua_err())?,
 		})
 	}
 
-	#[inline]
 	fn key_to_value(lua: &Lua, key: DataKey) -> mlua::Result<Value> {
 		match key {
 			DataKey::Url(u) => yazi_binding::Url::new(u).into_lua(lua),
-			DataKey::Urn(u) => yazi_binding::Urn::new(u).into_lua(lua),
+			DataKey::Path(u) => yazi_binding::Path::new(u).into_lua(lua),
 			_ => Self::key_to_value_ref(lua, &key),
 		}
 	}
@@ -225,11 +240,12 @@ impl Sendable {
 			DataKey::Nil => Value::Nil,
 			DataKey::Boolean(b) => Value::Boolean(*b),
 			DataKey::Integer(i) => Value::Integer(*i),
-			DataKey::Number(n) => Value::Number(n.get()),
-			DataKey::String(s) => Value::String(lua.create_string(s.as_ref())?),
+			DataKey::Number(n) => Value::Number(n.0),
+			DataKey::String(s) => Value::String(lua.create_string(&**s)?),
 			DataKey::Id(i) => yazi_binding::Id(*i).into_lua(lua)?,
-			DataKey::Url(u) => yazi_binding::Url::new(u.clone()).into_lua(lua)?,
-			DataKey::Urn(u) => yazi_binding::Urn::new(u.clone()).into_lua(lua)?,
+			DataKey::Url(u) => yazi_binding::Url::new(u).into_lua(lua)?,
+			DataKey::Path(u) => yazi_binding::Path::new(u).into_lua(lua)?,
+			DataKey::Bytes(b) => Value::String(lua.create_string(b)?),
 		})
 	}
 }
