@@ -1,11 +1,13 @@
-use std::{collections::HashMap, str::FromStr, time::Duration};
+use std::{str::FromStr, time::Duration};
 
 use anyhow::Result;
+use hashbrown::HashMap;
 use parking_lot::RwLock;
 use tokio::{io::{AsyncBufReadExt, AsyncWriteExt, BufReader}, select, sync::mpsc::{self, UnboundedReceiver}, task::JoinHandle, time};
+use yazi_macro::try_format;
 use yazi_shared::{Id, RoCell};
 
-use crate::{Client, ClientWriter, Payload, Peer, STATE, Stream, body::{Body, BodyBye, BodyHey}};
+use crate::{Client, ClientWriter, Payload, Peer, STATE, Stream, ember::{Ember, EmberBye, EmberHey}};
 
 pub(super) static CLIENTS: RoCell<RwLock<HashMap<Id, Client>>> = RoCell::new();
 
@@ -50,7 +52,7 @@ impl Server {
 
 								let mut parts = line.splitn(4, ',');
 								let Some(kind) = parts.next() else { continue };
-								let Some(receiver) = parts.next().and_then(|s| s.parse().ok()) else { continue };
+								let Some(receiver) = parts.next().and_then(|s| s.parse::<Id>().ok()) else { continue };
 								let Some(sender) = parts.next().and_then(|s| s.parse::<u64>().ok()) else { continue };
 
 								let clients = CLIENTS.read();
@@ -89,12 +91,12 @@ impl Server {
 
 	fn handle_hi(s: String, id: &mut Option<Id>, tx: mpsc::UnboundedSender<String>) {
 		let Ok(payload) = Payload::from_str(&s) else { return };
-		let Body::Hi(hi) = payload.body else { return };
+		let Ember::Hi(hi) = payload.body else { return };
 
-		if id.is_none() {
-			if let Some(ref state) = *STATE.read() {
-				state.values().for_each(|s| _ = tx.send(s.clone()));
-			}
+		if id.is_none()
+			&& let Some(ref state) = *STATE.read()
+		{
+			state.values().for_each(|s| _ = tx.send(s.clone()));
 		}
 
 		let mut clients = CLIENTS.write();
@@ -109,13 +111,12 @@ impl Server {
 	}
 
 	fn handle_hey(clients: &HashMap<Id, Client>) {
-		let payload = format!(
-			"{}\n",
-			Payload::new(BodyHey::owned(
-				clients.values().map(|c| (c.id, Peer::new(&c.abilities))).collect()
-			))
-		);
-		clients.values().for_each(|c| _ = c.tx.send(payload.clone()));
+		let payload = Payload::new(EmberHey::owned(
+			clients.values().map(|c| (c.id, Peer::new(&c.abilities))).collect(),
+		));
+		if let Ok(s) = try_format!("{payload}\n") {
+			clients.values().for_each(|c| _ = c.tx.send(s.clone()));
+		}
 	}
 
 	async fn handle_bye(id: Id, mut rx: UnboundedReceiver<String>, mut writer: ClientWriter) {
@@ -125,10 +126,10 @@ impl Server {
 			}
 		}
 
-		_ = writer
-			.write_all(BodyBye::owned().with_receiver(id).with_sender(Id(0)).to_string().as_bytes())
-			.await;
-
-		writer.flush().await.ok();
+		let bye = EmberBye::owned().with_receiver(id).with_sender(Id(0));
+		if let Ok(s) = try_format!("{bye}") {
+			writer.write_all(s.as_bytes()).await.ok();
+			writer.flush().await.ok();
+		}
 	}
 }
