@@ -36,9 +36,11 @@ impl Stream {
 
 	#[cfg(unix)]
 	pub(super) async fn bind() -> std::io::Result<ServerListener> {
+		use yazi_fs::provider::Provider;
+
 		let p = Self::socket_file();
 
-		tokio::fs::remove_file(&p).await.ok();
+		yazi_fs::provider::local::Local::regular(&p).remove_file().await.ok();
 		tokio::net::UnixListener::bind(p)
 	}
 
