@@ -1,15 +1,15 @@
-use ratatui::{buffer::Buffer, layout::{self, Alignment, Constraint, Rect}, text::{Line, Text}, widgets::{Block, BorderType, List, Padding, Widget}};
+use ratatui::{buffer::Buffer, layout::{self, Alignment, Constraint, Rect}, text::Line, widgets::{Block, BorderType, Widget}};
 use yazi_config::THEME;
-use yazi_core::tasks::TASKS_PERCENT;
+use yazi_core::{Core, tasks::TASKS_PERCENT};
 
-use crate::Ctx;
+use crate::tasks::List;
 
 pub(crate) struct Tasks<'a> {
-	cx: &'a Ctx,
+	core: &'a Core,
 }
 
 impl<'a> Tasks<'a> {
-	pub(crate) fn new(cx: &'a Ctx) -> Self { Self { cx } }
+	pub(crate) fn new(core: &'a Core) -> Self { Self { core } }
 
 	pub(super) fn area(area: Rect) -> Rect {
 		let chunk = layout::Layout::vertical([
@@ -32,27 +32,15 @@ impl Widget for Tasks<'_> {
 	fn render(self, area: Rect, buf: &mut Buffer) {
 		let area = Self::area(area);
 
-		yazi_plugin::elements::Clear::default().render(area, buf);
+		yazi_binding::elements::Clear::default().render(area, buf);
+
 		let block = Block::bordered()
 			.title(Line::styled("Tasks", THEME.tasks.title))
 			.title_alignment(Alignment::Center)
-			.padding(Padding::symmetric(1, 1))
 			.border_type(BorderType::Rounded)
 			.border_style(THEME.tasks.border);
+		(&block).render(area, buf);
 
-		let inner = block.inner(area);
-		block.render(area, buf);
-
-		let tasks = &self.cx.tasks;
-		let items = tasks.summaries.iter().take(inner.height as usize).enumerate().map(|(i, v)| {
-			let mut item =
-				Text::from_iter(textwrap::wrap(&v.name, inner.width as usize).into_iter().map(Line::from));
-			if i == tasks.cursor {
-				item = item.style(THEME.tasks.hovered);
-			}
-			item
-		});
-
-		List::new(items).render(inner, buf);
+		List::new(self.core).render(block.inner(area), buf);
 	}
 }
