@@ -1,10 +1,10 @@
 use std::{io, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, Ordering}};
 
 use anyhow::Result;
-use crossterm::{Command, event::{DisableBracketedPaste, DisableMouseCapture, EnableBracketedPaste, EnableMouseCapture, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{EnterAlternateScreen, LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
+use crossterm::{event::{DisableBracketedPaste, DisableMouseCapture, EnableBracketedPaste, EnableMouseCapture, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{EnterAlternateScreen, LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
 use ratatui::{CompletedFrame, Frame, Terminal, backend::CrosstermBackend, buffer::Buffer, layout::Rect};
 use yazi_adapter::{Emulator, Mux, TMUX};
-use yazi_config::YAZI;
+use yazi_config::{THEME, YAZI};
 use yazi_shared::SyncCell;
 use yazi_term::tty::{TTY, TtyWriter};
 
@@ -18,7 +18,6 @@ pub(super) struct Term {
 
 impl Term {
 	pub(super) fn start() -> Result<Self> {
-		static SKIP: SyncCell<bool> = SyncCell::new(false);
 		let mut term = Self {
 			inner:       Terminal::new(CrosstermBackend::new(TTY.writer()))?,
 			last_area:   Default::default(),
@@ -26,7 +25,8 @@ impl Term {
 		};
 
 		enable_raw_mode()?;
-		if SKIP.replace(true) && yazi_adapter::TMUX.get() {
+		static FIRST: SyncCell<bool> = SyncCell::new(false);
+		if FIRST.replace(true) && yazi_adapter::TMUX.get() {
 			yazi_adapter::Mux::tmux_passthrough();
 		}
 
@@ -34,25 +34,28 @@ impl Term {
 			TTY.writer(),
 			yazi_term::If(!TMUX.get(), EnterAlternateScreen),
 			Print("\x1bP$q q\x1b\\"), // Request cursor shape (DECRQSS query for DECSCUSR)
-			Print(Mux::csi("\x1b[?12$p")), // Request cursor blink status (DECSET)
+			Print("\x1b[?12$p"),      // Request cursor blink status (DECRQM query for DECSET 12)
 			Print("\x1b[?u"),         // Request keyboard enhancement flags (CSI u)
-			Print(Mux::csi("\x1b[0c")), // Request device attributes
+			Print("\x1b[0c"),         // Request device attributes
 			yazi_term::If(TMUX.get(), EnterAlternateScreen),
+			yazi_term::SetBackground(true, THEME.app.bg_color()), // Set app background
 			EnableBracketedPaste,
-			yazi_term::If(!YAZI.mgr.mouse_events.is_empty(), EnableMouseCapture),
+			yazi_term::If(!YAZI.mgr.mouse_events.get().is_empty(), EnableMouseCapture),
 		)?;
 
 		let resp = Emulator::read_until_da1();
 		Mux::tmux_drain()?;
-		yazi_term::RestoreCursor::store(&resp);
 
+		yazi_term::RestoreCursor::store(&resp);
 		CSI_U.store(resp.contains("\x1b[?0u"), Ordering::Relaxed);
 		if CSI_U.load(Ordering::Relaxed) {
-			PushKeyboardEnhancementFlags(
-				KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES
-					| KeyboardEnhancementFlags::REPORT_ALTERNATE_KEYS,
-			)
-			.write_ansi(&mut TTY.writer())?;
+			_ = queue!(
+				TTY.writer(),
+				PushKeyboardEnhancementFlags(
+					KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES
+						| KeyboardEnhancementFlags::REPORT_ALTERNATE_KEYS,
+				)
+			);
 		}
 
 		if let Some(s) = YAZI.mgr.title() {
@@ -67,7 +70,7 @@ impl Term {
 
 	fn stop(&mut self) -> Result<()> {
 		if CSI_U.swap(false, Ordering::Relaxed) {
-			PopKeyboardEnhancementFlags.write_ansi(&mut TTY.writer())?;
+			queue!(TTY.writer(), PopKeyboardEnhancementFlags).ok();
 		}
 
 		if !YAZI.mgr.title_format.is_empty() {
@@ -76,7 +79,7 @@ impl Term {
 
 		execute!(
 			TTY.writer(),
-			yazi_term::If(!YAZI.mgr.mouse_events.is_empty(), DisableMouseCapture),
+			yazi_term::If(!YAZI.mgr.mouse_events.get().is_empty(), DisableMouseCapture),
 			yazi_term::RestoreCursor,
 			DisableBracketedPaste,
 			LeaveAlternateScreen,
@@ -88,7 +91,7 @@ impl Term {
 
 	pub(super) fn goodbye(f: impl FnOnce() -> i32) -> ! {
 		if CSI_U.swap(false, Ordering::Relaxed) {
-			PopKeyboardEnhancementFlags.write_ansi(&mut TTY.writer()).ok();
+			queue!(TTY.writer(), PopKeyboardEnhancementFlags).ok();
 		}
 
 		if !YAZI.mgr.title_format.is_empty() {
@@ -97,7 +100,8 @@ impl Term {
 
 		execute!(
 			TTY.writer(),
-			yazi_term::If(!YAZI.mgr.mouse_events.is_empty(), DisableMouseCapture),
+			yazi_term::If(!YAZI.mgr.mouse_events.get().is_empty(), DisableMouseCapture),
+			yazi_term::SetBackground(false, THEME.app.bg_color()),
 			yazi_term::RestoreCursor,
 			DisableBracketedPaste,
 			LeaveAlternateScreen,
@@ -110,7 +114,7 @@ impl Term {
 		std::process::exit(f());
 	}
 
-	pub(super) fn draw(&mut self, f: impl FnOnce(&mut Frame)) -> io::Result<CompletedFrame> {
+	pub(super) fn draw(&mut self, f: impl FnOnce(&mut Frame)) -> io::Result<CompletedFrame<'_>> {
 		let last = self.inner.draw(f)?;
 
 		self.last_area = last.area;
@@ -118,7 +122,10 @@ impl Term {
 		Ok(last)
 	}
 
-	pub(super) fn draw_partial(&mut self, f: impl FnOnce(&mut Frame)) -> io::Result<CompletedFrame> {
+	pub(super) fn draw_partial(
+		&mut self,
+		f: impl FnOnce(&mut Frame),
+	) -> io::Result<CompletedFrame<'_>> {
 		self.inner.draw(|frame| {
 			let buffer = frame.buffer_mut();
 			for y in self.last_area.top()..self.last_area.bottom() {
@@ -133,7 +140,6 @@ impl Term {
 		})
 	}
 
-	#[inline]
 	pub(super) fn can_partial(&mut self) -> bool {
 		self.inner.autoresize().is_ok() && self.last_area == self.inner.get_frame().area()
 	}
