@@ -1,6 +1,7 @@
-use std::{borrow::Cow, collections::{HashMap, HashSet}, ffi::{OsStr, OsString}, os::{fd::AsFd, unix::{ffi::{OsStrExt, OsStringExt}, fs::MetadataExt}}, time::Duration};
+use std::{borrow::Cow, ffi::{OsStr, OsString}, os::{fd::AsFd, unix::{ffi::{OsStrExt, OsStringExt}, fs::MetadataExt}}, time::Duration};
 
 use anyhow::{Context, Result};
+use hashbrown::{HashMap, HashSet};
 use tokio::{io::{Interest, unix::AsyncFd}, time::sleep};
 use tracing::error;
 use yazi_shared::{natsort, replace_cow, replace_vec_cow};
@@ -8,22 +9,22 @@ use yazi_shared::{natsort, replace_cow, replace_vec_cow};
 use super::{Locked, Partition, Partitions};
 
 impl Partitions {
-	pub fn monitor<F>(me: Locked, cb: F)
+	pub fn monitor<F>(me: &'static Locked, cb: F)
 	where
 		F: Fn() + Copy + Send + 'static,
 	{
-		async fn wait_mounts(me: Locked, cb: impl Fn()) -> Result<()> {
+		async fn wait_mounts(me: &'static Locked, cb: impl Fn()) -> Result<()> {
 			let f = std::fs::File::open("/proc/mounts")?;
 			let fd = AsyncFd::with_interest(f.as_fd(), Interest::READABLE)?;
 			loop {
 				let mut guard = fd.readable().await?;
 				guard.clear_ready();
-				Partitions::update(me.clone()).await;
+				Partitions::update(me).await;
 				cb();
 			}
 		}
 
-		async fn wait_partitions(me: Locked, cb: impl Fn()) -> Result<()> {
+		async fn wait_partitions(me: &'static Locked, cb: impl Fn()) -> Result<()> {
 			loop {
 				let partitions = Partitions::partitions()?;
 				if me.read().linux_cache == partitions {
@@ -32,17 +33,16 @@ impl Partitions {
 				}
 
 				me.write().linux_cache = partitions;
-				Partitions::update(me.clone()).await;
+				Partitions::update(me).await;
 
 				cb();
 				sleep(Duration::from_secs(3)).await;
 			}
 		}
 
-		let me_ = me.clone();
 		tokio::spawn(async move {
 			loop {
-				if let Err(e) = wait_mounts(me_.clone(), cb).await {
+				if let Err(e) = wait_mounts(me, cb).await {
 					error!("Error encountered while monitoring /proc/mounts: {e:?}");
 				}
 				sleep(Duration::from_secs(5)).await;
@@ -51,7 +51,7 @@ impl Partitions {
 
 		tokio::spawn(async move {
 			loop {
-				if let Err(e) = wait_partitions(me.clone(), cb).await {
+				if let Err(e) = wait_partitions(me, cb).await {
 					error!("Error encountered while monitoring /proc/partitions: {e:?}");
 				}
 				sleep(Duration::from_secs(5)).await;
@@ -74,7 +74,7 @@ impl Partitions {
 		Ok(set)
 	}
 
-	async fn update(me: Locked) {
+	async fn update(me: &'static Locked) {
 		_ = tokio::task::spawn_blocking(move || {
 			let mut guard = me.write();
 			match Self::all(&guard) {
@@ -164,15 +164,12 @@ impl Partitions {
 
 	// Unmangle '\t', '\n', ' ', '#', and r'\'
 	// https://elixir.bootlin.com/linux/v6.13-rc3/source/fs/proc_namespace.c#L89
-	fn unmangle_octal(s: &str) -> Cow<str> {
+	fn unmangle_octal(s: &str) -> Cow<'_, str> {
 		let mut s = Cow::Borrowed(s);
 		for (a, b) in
 			[(r"\011", "\t"), (r"\012", "\n"), (r"\040", " "), (r"\043", "#"), (r"\134", r"\")]
 		{
-			s = match replace_cow(&s, a, b) {
-				Cow::Borrowed(_) => s,
-				Cow::Owned(new) => Cow::Owned(new),
-			};
+			s = replace_cow(s, a, b);
 		}
 		s
 	}
