@@ -1,4 +1,4 @@
-use std::{ops::Deref, sync::Arc};
+use std::ops::Deref;
 
 use parking_lot::RwLock;
 use yazi_shared::RoCell;
@@ -6,7 +6,7 @@ use yazi_shared::RoCell;
 use super::Partition;
 use crate::cha::Cha;
 
-pub(super) type Locked = Arc<RwLock<Partitions>>;
+pub(super) type Locked = RwLock<Partitions>;
 
 pub static PARTITIONS: RoCell<Locked> = RoCell::new();
 
@@ -14,7 +14,7 @@ pub static PARTITIONS: RoCell<Locked> = RoCell::new();
 pub struct Partitions {
 	pub(super) inner:       Vec<Partition>,
 	#[cfg(target_os = "linux")]
-	pub(super) linux_cache: std::collections::HashSet<String>,
+	pub(super) linux_cache: hashbrown::HashSet<String>,
 	#[cfg(target_os = "macos")]
 	pub(super) need_update: bool,
 }
@@ -26,9 +26,8 @@ impl Deref for Partitions {
 }
 
 impl Partitions {
-	#[inline]
 	#[cfg(unix)]
-	pub fn by_dev(&self, dev: libc::dev_t) -> Option<&Partition> {
+	pub fn by_dev(&self, dev: u64) -> Option<&Partition> {
 		self.inner.iter().find(|p| p.rdev == Some(dev))
 	}
 
