@@ -1,12 +1,12 @@
-use std::{env, path::PathBuf};
-
-use crate::expand_path;
+use std::{env, path::PathBuf, sync::OnceLock};
 
 pub struct Xdg;
 
 impl Xdg {
 	pub fn config_dir() -> PathBuf {
-		if let Some(p) = env::var_os("YAZI_CONFIG_HOME").map(expand_path).filter(|p| p.is_absolute()) {
+		if let Some(p) = env::var_os("YAZI_CONFIG_HOME").map(PathBuf::from)
+			&& p.is_absolute()
+		{
 			return p;
 		}
 
@@ -43,17 +43,22 @@ impl Xdg {
 		}
 	}
 
-	#[inline]
-	pub fn cache_dir() -> PathBuf {
-		#[cfg(unix)]
-		let s = {
-			use uzers::Users;
-			format!("yazi-{}", yazi_shared::USERS_CACHE.get_current_uid())
-		};
+	pub fn cache_dir() -> &'static PathBuf {
+		static CACHE: OnceLock<PathBuf> = OnceLock::new();
 
-		#[cfg(windows)]
-		let s = "yazi";
+		CACHE.get_or_init(|| {
+			let mut p = env::temp_dir();
+			assert!(p.is_absolute(), "Temp dir is not absolute");
 
-		env::temp_dir().join(s)
+			#[cfg(unix)]
+			{
+				use uzers::Users;
+				p.push(format!("yazi-{}", yazi_shared::USERS_CACHE.get_current_uid()))
+			}
+			#[cfg(not(unix))]
+			p.push("yazi");
+
+			p
+		})
 	}
 }
