@@ -33,7 +33,7 @@ function M:preload(job)
 		"-gravity",
 		"center",
 		"-font",
-		tostring(job.file.url),
+		tostring(job.file.path),
 		"-pointsize",
 		64,
 		"xc:white",
