@@ -2,11 +2,12 @@ use std::process::Stdio;
 
 use anyhow::Result;
 use tokio::{io::{AsyncBufReadExt, BufReader}, process::{Child, Command}, sync::mpsc::{self, UnboundedReceiver}};
-use yazi_fs::File;
-use yazi_shared::url::Url;
+use yazi_fs::{File, FsUrl};
+use yazi_shared::url::{AsUrl, UrlBuf, UrlLike};
+use yazi_vfs::VfsFile;
 
 pub struct FdOpt {
-	pub cwd:     Url,
+	pub cwd:     UrlBuf,
 	pub hidden:  bool,
 	pub subject: String,
 	pub args:    Vec<String>,
@@ -20,7 +21,10 @@ pub fn fd(opt: FdOpt) -> Result<UnboundedReceiver<File>> {
 
 	tokio::spawn(async move {
 		while let Ok(Some(line)) = it.next_line().await {
-			if let Ok(file) = File::new(opt.cwd.join(line)).await {
+			let Ok(url) = opt.cwd.try_join(line) else {
+				continue;
+			};
+			if let Ok(file) = File::new(url).await {
 				tx.send(file).ok();
 			}
 		}
@@ -32,7 +36,7 @@ pub fn fd(opt: FdOpt) -> Result<UnboundedReceiver<File>> {
 fn spawn(program: &str, opt: &FdOpt) -> std::io::Result<Child> {
 	Command::new(program)
 		.arg("--base-directory")
-		.arg(&opt.cwd)
+		.arg(&*opt.cwd.as_url().unified_path())
 		.arg("--regex")
 		.arg(if opt.hidden { "--hidden" } else { "--no-hidden" })
 		.args(&opt.args)
