@@ -1,10 +1,10 @@
 use mlua::{IntoLua, ObjectLike};
+use yazi_binding::{File, elements::Rect};
 use yazi_config::LAYOUT;
-use yazi_proxy::{AppProxy, options::{PluginCallback, PluginOpt}};
+use yazi_parser::app::{PluginCallback, PluginOpt};
+use yazi_proxy::AppProxy;
 use yazi_shared::event::Cmd;
 
-use crate::{elements::Rect, file::File};
-
 pub fn seek_sync(cmd: &'static Cmd, file: yazi_fs::File, units: i16) {
 	let cb: PluginCallback = Box::new(move |lua, plugin| {
 		let job = lua.create_table_from([
@@ -16,5 +16,5 @@ pub fn seek_sync(cmd: &'static Cmd, file: yazi_fs::File, units: i16) {
 		plugin.call_method("seek", job)
 	});
 
-	AppProxy::plugin(PluginOpt::new_callback(&cmd.name, cb));
+	AppProxy::plugin(PluginOpt::new_callback(&*cmd.name, cb));
 }
