@@ -1,22 +1,20 @@
-use std::borrow::Cow;
-
 use mlua::{ExternalError, ExternalResult, HookTriggers, IntoLua, ObjectLike, VmState};
 use tokio::{runtime::Handle, select};
 use tokio_util::sync::CancellationToken;
 use tracing::error;
-use yazi_binding::Id;
+use yazi_binding::{File, Id};
 use yazi_dds::Sendable;
-use yazi_shared::{Ids, event::Cmd};
+use yazi_shared::{Ids, event::Cmd, pool::Symbol};
 
 use super::slim_lua;
-use crate::{file::File, loader::LOADER};
+use crate::loader::LOADER;
 
 static IDS: Ids = Ids::new();
 
 pub fn spot(
 	cmd: &'static Cmd,
 	file: yazi_fs::File,
-	mime: Cow<'static, str>,
+	mime: Symbol<str>,
 	skip: usize,
 ) -> CancellationToken {
 	let ct = CancellationToken::new();
@@ -36,7 +34,7 @@ pub fn spot(
 						Ok(VmState::Continue)
 					}
 				},
-			);
+			)?;
 
 			let plugin = LOADER.load_once(&lua, &cmd.name)?;
 			let job = lua.create_table_from([
@@ -50,18 +48,15 @@ pub fn spot(
 			if ct2.is_cancelled() { Ok(()) } else { plugin.call_async_method("spot", job).await }
 		};
 
-		let result = Handle::current().block_on(async {
+		Handle::current().block_on(async {
 			select! {
-				_ = ct2.cancelled() => Ok(()),
-				r = future => r,
+				_ = ct2.cancelled() => {},
+				Err(e) = future => if !e.to_string().contains("Spot task cancelled") {
+					error!("{e}");
+				},
+				else => {}
 			}
 		});
-
-		if let Err(e) = result {
-			if !e.to_string().contains("Spot task cancelled") {
-				error!("{e}");
-			}
-		}
 	});
 
 	ct
