@@ -1,8 +1,9 @@
-use std::{io, process::Stdio};
+use std::{any::TypeId, ffi::OsStr, io, process::Stdio};
 
-use mlua::{AnyUserData, ExternalError, IntoLuaMulti, Lua, MetaMethod, Table, UserData, Value};
+use mlua::{AnyUserData, ExternalError, IntoLua, IntoLuaMulti, Lua, MetaMethod, Table, UserData, Value};
 use tokio::process::{ChildStderr, ChildStdin, ChildStdout};
 use yazi_binding::Error;
+use yazi_shared::wtf8::FromWtf8;
 
 use super::{Child, output::Output};
 use crate::process::Status;
@@ -32,7 +33,7 @@ impl Command {
 			("INHERIT", INHERIT),
 		])?;
 
-		command.set_metatable(Some(lua.create_table_from([(MetaMethod::Call.name(), new)])?));
+		command.set_metatable(Some(lua.create_table_from([(MetaMethod::Call.name(), new)])?))?;
 
 		lua.globals().raw_set("Command", command)
 	}
@@ -96,8 +97,8 @@ impl Command {
 	}
 
 	async fn output(&mut self) -> io::Result<std::process::Output> {
-		self.inner.stdin(Stdio::piped());
 		self.inner.stdout(Stdio::piped());
+		self.inner.stderr(Stdio::piped());
 		self.spawn()?.wait_with_output().await
 	}
 
@@ -118,15 +119,18 @@ impl UserData for Command {
 						_ => Stdio::null(),
 					});
 				}
-				Value::UserData(ud) => {
-					if let Ok(stdin) = ud.take::<ChildStdin>() {
-						return Ok(stdin.try_into()?);
-					} else if let Ok(stdout) = ud.take::<ChildStdout>() {
-						return Ok(stdout.try_into()?);
-					} else if let Ok(stderr) = ud.take::<ChildStderr>() {
-						return Ok(stderr.try_into()?);
+				Value::UserData(ud) => match ud.type_id() {
+					Some(t) if t == TypeId::of::<ChildStdin>() => {
+						return Ok(ud.take::<ChildStdin>()?.try_into()?);
 					}
-				}
+					Some(t) if t == TypeId::of::<ChildStdout>() => {
+						return Ok(ud.take::<ChildStdout>()?.try_into()?);
+					}
+					Some(t) if t == TypeId::of::<ChildStderr>() => {
+						return Ok(ud.take::<ChildStderr>()?.try_into()?);
+					}
+					_ => {}
+				},
 				_ => {}
 			}
 
@@ -135,37 +139,21 @@ impl UserData for Command {
 			)
 		}
 
-		methods.add_function_mut("arg", |_, (ud, arg): (AnyUserData, Value)| {
-			{
-				let mut me = ud.borrow_mut::<Self>()?;
-				match arg {
-					Value::String(s) => {
-						me.inner.arg(String::from_utf8_lossy(&s.as_bytes()).as_ref());
-					}
-					Value::Table(t) => {
-						for s in t.sequence_values::<mlua::String>() {
-							me.inner.arg(String::from_utf8_lossy(&s?.as_bytes()).as_ref());
-						}
-					}
-					_ => return Err("arg must be a string or table of strings".into_lua_err()),
+		methods.add_function_mut("arg", |lua, (ud, arg): (AnyUserData, Value)| {
+			let mut me = ud.borrow_mut::<Self>()?;
+			match arg {
+				Value::Nil => return lua.create_sequence_from(me.inner.as_std().get_args())?.into_lua(lua),
+				Value::String(s) => {
+					me.inner.arg(OsStr::from_wtf8(&s.as_bytes())?);
 				}
-			}
-			Ok(ud)
-		});
-		// TODO: remove this
-		methods.add_function_mut("args", |lua, (ud, args): (AnyUserData, Vec<mlua::String>)| {
-			crate::deprecate!(
-				lua,
-				"The `args()` method on `Command` is deprecated, use `arg()` instead in your {}\n\nSee #2752 for more details: https://github.com/sxyazi/yazi/pull/2752"
-			);
-
-			{
-				let mut me = ud.borrow_mut::<Self>()?;
-				for arg in args {
-					me.inner.arg(arg.to_string_lossy());
+				Value::Table(t) => {
+					for s in t.sequence_values::<mlua::String>() {
+						me.inner.arg(OsStr::from_wtf8(&s?.as_bytes())?);
+					}
 				}
+				_ => Err("arg must be a string or table of strings".into_lua_err())?,
 			}
-			Ok(ud)
+			ud.into_lua(lua)
 		});
 		methods.add_function_mut("cwd", |_, (ud, dir): (AnyUserData, mlua::String)| {
 			ud.borrow_mut::<Self>()?.inner.current_dir(dir.to_str()?.as_ref());
@@ -174,10 +162,9 @@ impl UserData for Command {
 		methods.add_function_mut(
 			"env",
 			|_, (ud, key, value): (AnyUserData, mlua::String, mlua::String)| {
-				ud.borrow_mut::<Self>()?.inner.env(
-					String::from_utf8_lossy(&key.as_bytes()).as_ref(),
-					String::from_utf8_lossy(&value.as_bytes()).as_ref(),
-				);
+				ud.borrow_mut::<Self>()?
+					.inner
+					.env(OsStr::from_wtf8(&key.as_bytes())?, OsStr::from_wtf8(&value.as_bytes())?);
 				Ok(ud)
 			},
 		);
