@@ -1,13 +1,10 @@
-#![allow(clippy::module_inception)]
-
 use mlua::{IntoLua, Lua, Value};
-
-use crate::Composer;
+use yazi_binding::{Composer, ComposerGet, ComposerSet};
 
 yazi_macro::mod_flat!(pubsub);
 
-pub(super) fn compose(lua: &Lua) -> mlua::Result<Value> {
-	Composer::make(lua, 10, |lua, key| {
+pub(super) fn compose() -> Composer<ComposerGet, ComposerSet> {
+	fn get(lua: &Lua, key: &[u8]) -> mlua::Result<Value> {
 		match key {
 			b"pub" => Pubsub::r#pub(lua)?,
 			b"pub_to" => Pubsub::pub_to(lua)?,
@@ -18,5 +15,9 @@ pub(super) fn compose(lua: &Lua) -> mlua::Result<Value> {
 			_ => return Ok(Value::Nil),
 		}
 		.into_lua(lua)
-	})
+	}
+
+	fn set(_: &Lua, _: &[u8], value: Value) -> mlua::Result<Value> { Ok(value) }
+
+	Composer::new(get, set)
 }
