@@ -3,36 +3,41 @@ use std::{str::FromStr, time::Duration};
 use mlua::{ExternalError, ExternalResult, Function, IntoLuaMulti, Lua, Table, Value};
 use tokio::sync::mpsc;
 use tokio_stream::wrappers::UnboundedReceiverStream;
+use yazi_binding::{deprecate, elements::{Line, Pos, Text}, runtime};
 use yazi_config::{keymap::{Chord, Key}, popup::{ConfirmCfg, InputCfg}};
-use yazi_macro::emit;
-use yazi_proxy::{AppProxy, ConfirmProxy, InputProxy};
-use yazi_shared::{Debounce, event::Cmd};
+use yazi_macro::relay;
+use yazi_parser::which::ShowOpt;
+use yazi_proxy::{AppProxy, ConfirmProxy, InputProxy, WhichProxy};
+use yazi_shared::Debounce;
 
 use super::Utils;
-use crate::{bindings::InputRx, elements::{Line, Pos, Text}};
+use crate::bindings::InputRx;
 
 impl Utils {
 	pub(super) fn which(lua: &Lua) -> mlua::Result<Function> {
-		lua.create_async_function(|_, t: Table| async move {
-			let (tx, mut rx) = mpsc::channel::<usize>(1);
-
-			let mut cands = Vec::with_capacity(30);
-			for (i, cand) in t.raw_get::<Table>("cands")?.sequence_values::<Table>().enumerate() {
-				let cand = cand?;
-				cands.push(Chord {
-					on:    Self::parse_keys(cand.raw_get("on")?)?,
-					run:   vec![Cmd::args("which:callback", &[i]).with_any("tx", tx.clone())],
-					desc:  cand.raw_get("desc").ok(),
-					r#for: None,
-				});
+		lua.create_async_function(|lua, t: Table| async move {
+			if runtime!(lua)?.initing {
+				return Err("Cannot call `ya.which()` during app initialization".into_lua_err());
 			}
 
+			let (tx, mut rx) = mpsc::channel::<usize>(1);
+			let cands: Vec<_> = t
+				.raw_get::<Table>("cands")?
+				.sequence_values::<Table>()
+				.enumerate()
+				.map(|(i, cand)| {
+					let cand = cand?;
+					Ok(Chord {
+						on:    Self::parse_keys(cand.raw_get("on")?)?,
+						run:   vec![relay!(which:callback, [i]).with_any("tx", tx.clone())],
+						desc:  cand.raw_get("desc").ok(),
+						r#for: None,
+					})
+				})
+				.collect::<mlua::Result<_>>()?;
+
 			drop(tx);
-			emit!(Call(
-				Cmd::new("which:show")
-					.with_any("candidates", cands)
-					.with_bool("silent", t.raw_get("silent").unwrap_or_default())
-			));
+			WhichProxy::show(ShowOpt { cands, silent: t.raw_get("silent").unwrap_or_default() });
 
 			Ok(rx.recv().await.map(|idx| idx + 1))
 		})
@@ -40,13 +45,25 @@ impl Utils {
 
 	pub(super) fn input(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_async_function(|lua, t: Table| async move {
+			if runtime!(lua)?.initing {
+				return Err("Cannot call `ya.input()` during app initialization".into_lua_err());
+			}
+
+			let mut pos = t.raw_get::<Value>("pos")?;
+			if pos.is_nil() {
+				pos = t.raw_get("position")?;
+				if !pos.is_nil() {
+					deprecate!(lua, "The `position` property of `ya.input()` is deprecated, use `pos` instead in your {}\nSee #2921 for more details: https://github.com/sxyazi/yazi/pull/2921");
+				}
+			}
+
 			let realtime = t.raw_get("realtime").unwrap_or_default();
 			let rx = UnboundedReceiverStream::new(InputProxy::show(InputCfg {
 				title: t.raw_get("title")?,
 				value: t.raw_get("value").unwrap_or_default(),
 				cursor: None, // TODO
 				obscure: t.raw_get("obscure").unwrap_or_default(),
-				position: Pos::new_input(t.raw_get::<Table>("position")?)?.into(),
+				position: Pos::new_input(pos)?.into(),
 				realtime,
 				completion: false,
 			}));
@@ -67,18 +84,22 @@ impl Utils {
 	}
 
 	pub(super) fn confirm(lua: &Lua) -> mlua::Result<Function> {
-		fn content(t: &Table) -> mlua::Result<ratatui::widgets::Paragraph<'static>> {
-			Ok(match t.raw_get::<Value>("content")? {
+		fn body(t: &Table) -> mlua::Result<ratatui::widgets::Paragraph<'static>> {
+			Ok(match t.raw_get::<Value>("body")? {
 				Value::Nil => Default::default(),
 				v => Text::try_from(v)?.into(),
 			})
 		}
 
-		lua.create_async_function(|_, t: Table| async move {
+		lua.create_async_function(|lua, t: Table| async move {
+			if runtime!(lua)?.initing {
+				return Err("Cannot call `ya.confirm()` during app initialization".into_lua_err());
+			}
+
 			let result = ConfirmProxy::show(ConfirmCfg {
-				position: Pos::try_from(t.raw_get::<Table>("pos")?)?.into(),
+				position: Pos::try_from(t.raw_get::<Value>("pos")?)?.into(),
 				title:    Line::try_from(t.raw_get::<Value>("title")?)?.into(),
-				content:  content(&t)?,
+				body:     body(&t)?,
 				list:     Default::default(), // TODO
 			});
 
