@@ -1,31 +1,39 @@
+use anyhow::Context;
 use futures::future::join_all;
 use mlua::{ExternalError, ExternalResult, Function, IntoLuaMulti, Lua, MultiValue, Value, Variadic};
 use tokio::sync::oneshot;
+use yazi_binding::{Handle, runtime, runtime_mut};
 use yazi_dds::Sendable;
-use yazi_proxy::{AppProxy, options::{PluginCallback, PluginOpt}};
-use yazi_shared::event::Data;
+use yazi_parser::app::{PluginCallback, PluginOpt};
+use yazi_proxy::AppProxy;
+use yazi_shared::{LOCAL_SET, data::Data};
 
 use super::Utils;
-use crate::{RtRefMut, bindings::{MpscRx, MpscTx, MpscUnboundedRx, MpscUnboundedTx, OneshotRx, OneshotTx}, loader::LOADER, runtime::RtRef};
+use crate::{bindings::{MpscRx, MpscTx, MpscUnboundedRx, MpscUnboundedTx, OneshotRx, OneshotTx}, loader::LOADER};
 
 impl Utils {
 	pub(super) fn sync(lua: &Lua, isolate: bool) -> mlua::Result<Function> {
 		if isolate {
 			lua.create_function(|lua, ()| {
-				let Some(block) = lua.named_registry_value::<RtRefMut>("ir")?.next_block() else {
+				let Some(block) = runtime_mut!(lua)?.next_block() else {
 					return Err("`ya.sync()` must be called in a plugin").into_lua_err();
 				};
 
 				lua.create_async_function(move |lua, args: MultiValue| async move {
-					let Some(cur) = lua.named_registry_value::<RtRef>("ir")?.current_owned() else {
-						return Err("block spawned by `ya.sync()` must be called in a plugin").into_lua_err();
+					let Some(cur) = runtime!(lua)?.current_owned() else {
+						return Err("`ya.sync()` block must be used within a plugin").into_lua_err();
 					};
-					Sendable::list_to_values(&lua, Self::retrieve(cur, block, args).await?)
+
+					Self::retrieve(&lua, &cur, block, args)
+						.await
+						.and_then(|data| Sendable::list_to_values(&lua, data))
+						.with_context(|| format!("Failed to execute sync block-{block} in `{cur}` plugin"))
+						.into_lua_err()
 				})
 			})
 		} else {
 			lua.create_function(|lua, f: Function| {
-				let mut rt = lua.named_registry_value::<RtRefMut>("ir")?;
+				let mut rt = runtime_mut!(lua)?;
 				if !rt.put_block(f.clone()) {
 					return Err("`ya.sync()` must be called in a plugin").into_lua_err();
 				}
@@ -39,6 +47,29 @@ impl Utils {
 		}
 	}
 
+	pub(super) fn r#async(lua: &Lua, isolate: bool) -> mlua::Result<Function> {
+		if isolate {
+			lua.create_function(|_, _: Function| {
+				Err::<(), _>("`ya.async()` can only be used in sync context at the moment".into_lua_err())
+			})
+		} else {
+			lua.create_function(|lua, (f, args): (Function, MultiValue)| {
+				let name = runtime!(lua)?.current_owned();
+
+				Ok(Handle::AsyncFn(LOCAL_SET.spawn_local(async move {
+					let result = f.call_async::<MultiValue>(args).await;
+					if let Err(ref e) = result {
+						match name {
+							Some(s) => tracing::error!("Failed to execute async block in `{s}` plugin: {e}"),
+							None => tracing::error!("Failed to execute async block in `init.lua`: {e}"),
+						}
+					}
+					result
+				})))
+			})
+		}
+	}
+
 	pub(super) fn chan(lua: &Lua) -> mlua::Result<Function> {
 		lua.create_function(|lua, (r#type, buffer): (mlua::String, Option<usize>)| {
 			match (&*r#type.as_bytes(), buffer) {
@@ -77,14 +108,19 @@ impl Utils {
 		lua.create_async_function(|_lua, _futs: MultiValue| async move { Ok(()) })
 	}
 
-	async fn retrieve(id: String, calls: usize, args: MultiValue) -> mlua::Result<Vec<Data>> {
-		let args = Sendable::values_to_list(args)?;
+	async fn retrieve(
+		lua: &Lua,
+		id: &str,
+		calls: usize,
+		args: MultiValue,
+	) -> mlua::Result<Vec<Data>> {
+		let args = Sendable::values_to_list(lua, args)?;
 		let (tx, rx) = oneshot::channel::<Vec<Data>>();
 
 		let callback: PluginCallback = {
-			let id = id.clone();
+			let id = id.to_owned();
 			Box::new(move |lua, plugin| {
-				let Some(block) = lua.named_registry_value::<RtRef>("ir")?.get_block(&id, calls) else {
+				let Some(block) = runtime!(lua)?.get_block(&id, calls) else {
 					return Err("sync block not found".into_lua_err());
 				};
 
@@ -93,14 +129,13 @@ impl Utils {
 					.chain(args.into_iter().map(|d| Sendable::data_to_value(lua, d)))
 					.collect::<mlua::Result<MultiValue>>()?;
 
-				let values = Sendable::values_to_list(block.call(args)?)?;
+				let values = Sendable::values_to_list(lua, block.call(args)?)?;
 				tx.send(values).map_err(|_| "send failed".into_lua_err())
 			})
 		};
 
-		AppProxy::plugin(PluginOpt::new_callback(id.clone(), callback));
+		AppProxy::plugin(PluginOpt::new_callback(id.to_owned(), callback));
 
-		rx.await
-			.map_err(|_| format!("Failed to execute sync block-{calls} in `{id}` plugin").into_lua_err())
+		rx.await.into_lua_err()
 	}
 }
