@@ -28,6 +28,8 @@ impl Status {
 
 	pub fn is_eof(&self) -> bool { self.code == StatusCode::Eof }
 
+	pub fn is_failure(&self) -> bool { self.code == StatusCode::Failure }
+
 	pub(crate) fn connection_lost(id: u32) -> Self {
 		Self {
 			id,
@@ -40,13 +42,18 @@ impl Status {
 
 #[derive(Debug, Clone, Copy, PartialEq, Deserialize, Serialize)]
 pub enum StatusCode {
-	Ok               = 0,
-	Eof              = 1,
-	NoSuchFile       = 2,
-	PermissionDenied = 3,
-	Failure          = 4,
-	BadMessage       = 5,
-	NoConnection     = 6,
-	ConnectionLost   = 7,
-	OpUnsupported    = 8,
+	Ok                = 0,
+	Eof               = 1,
+	NoSuchFile        = 2,
+	PermissionDenied  = 3,
+	Failure           = 4,
+	BadMessage        = 5,
+	NoConnection      = 6,
+	ConnectionLost    = 7,
+	OpUnsupported     = 8,
+	InvalidHandle     = 9,
+	NoSuchPath        = 10,
+	FileAlreadyExists = 11,
+	WriteProtect      = 12,
+	NoMedia           = 13,
 }
