@@ -1,14 +1,12 @@
+use anyhow::Result;
+use yazi_macro::{act, succ};
+use yazi_parser::VoidOpt;
+use yazi_shared::data::Data;
+
 use crate::input::{Input, InputMode, op::InputOp};
 
-struct Opt;
-
-impl From<()> for Opt {
-	fn from(_: ()) -> Self { Self }
-}
-
 impl Input {
-	#[yazi_codegen::command]
-	pub fn escape(&mut self, _: Opt) {
+	pub fn escape(&mut self, _: VoidOpt) -> Result<Data> {
 		let snap = self.snap_mut();
 		match snap.mode {
 			InputMode::Normal => {
@@ -16,12 +14,13 @@ impl Input {
 			}
 			InputMode::Insert => {
 				snap.mode = InputMode::Normal;
-				self.r#move(-1);
+				act!(r#move, self, -1)?;
 			}
 			InputMode::Replace => {
 				snap.mode = InputMode::Normal;
 			}
 		}
 		self.snaps.tag(self.limit);
+		succ!();
 	}
 }
